# ncurses 5.9 - patch  - Thomas E. Dickey
#
# ------------------------------------------------------------------------------
#
# Ncurses 5.9 is at
# 	ftp.gnu.org:/pub/gnu
#
# Patches for ncurses 5.9 are in the subdirectory
# 	ftp://invisible-island.net/ncurses/5.9
#
# ------------------------------------------------------------------------------
# ftp://invisible-island.net/ncurses/5.9/ncurses-5.9-20140125.patch.gz
# patch by Thomas E. Dickey <dickey@invisible-island.net>
# created  Sun Jan 26 01:51:00 UTC 2014
# ------------------------------------------------------------------------------
# Ada95/gen/gen.c                  |   70 ++++++++++++-------------------------
# NEWS                             |    8 +++-
# dist.mk                          |    4 +-
# package/debian-mingw/changelog   |    4 +-
# package/debian-mingw64/changelog |    4 +-
# package/debian/changelog         |    4 +-
# package/mingw-ncurses.nsi        |    4 +-
# package/mingw-ncurses.spec       |    2 -
# package/ncurses.spec             |    2 -
# 9 files changed, 42 insertions(+), 60 deletions(-)
# ------------------------------------------------------------------------------
Index: Ada95/gen/gen.c
Prereq:  1.61 
--- ncurses-5.9-20140118+/Ada95/gen/gen.c	2013-08-24 23:30:46.000000000 +0000
+++ ncurses-5.9-20140125/Ada95/gen/gen.c	2014-01-26 00:21:52.000000000 +0000
@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 1998-2011,2013 Free Software Foundation, Inc.              *
+ * Copyright (c) 1998-2013,2014 Free Software Foundation, Inc.              *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -32,7 +32,7 @@
 
 /*
     Version Control
-    $Id: gen.c,v 1.61 2013/08/24 23:30:46 tom Exp $
+    $Id: gen.c,v 1.62 2014/01/26 00:21:52 Nicolas.Boulenguez Exp $
   --------------------------------------------------------------------------*/
 /*
   This program generates various record structures and constants from the
@@ -116,6 +116,7 @@
  * record type defined in the binding.
  * We are only dealing with record types which are of 32 or 16
  * bit size, i.e. they fit into an (u)int or a (u)short.
+ * Any pair with a 0 attr field will be ignored.
  */
 static void
 gen_reps(
@@ -132,19 +133,21 @@
   assert(nap != NULL);
 
   for (i = 0; nap[i].name != (char *)0; i++)
-    {
-      l = (int)strlen(nap[i].name);
-      if (l > width)
-	width = l;
-    }
+    if (nap[i].attr)
+      {
+	l = (int)strlen(nap[i].name);
+	if (l > width)
+	  width = l;
+      }
   assert(width > 0);
 
   printf("   type %s is\n", name);
   printf("      record\n");
   for (i = 0; nap[i].name != (char *)0; i++)
-    {
-      printf("         %-*s : Boolean;\n", width, nap[i].name);
-    }
+    if (nap[i].attr)
+      {
+	printf("         %-*s : Boolean;\n", width, nap[i].name);
+      }
   printf("      end record;\n");
   printf("   pragma Convention (C, %s);\n\n", name);
 
@@ -152,13 +155,14 @@
   printf("      record\n");
 
   for (i = 0; nap[i].name != (char *)0; i++)
-    {
-      a = nap[i].attr;
-      l = find_pos((char *)&a, sizeof(a), &low, &high);
-      if (l >= 0)
-	printf("         %-*s at 0 range %2d .. %2d;\n", width, nap[i].name,
-	       low - bias, high - bias);
-    }
+    if (nap[i].attr)
+      {
+	a = nap[i].attr;
+	l = find_pos((char *)&a, sizeof(a), &low, &high);
+	if (l >= 0)
+	  printf("         %-*s at 0 range %2d .. %2d;\n", width, nap[i].name,
+		 low - bias, high - bias);
+      }
   printf("      end record;\n");
   printf("   pragma Warnings (Off);");
   printf("   for %s'Size use %d;\n", name, len_bits);
@@ -243,54 +247,26 @@
    * 1999-2000), the ifdef's also were needed since the proposed bit-layout
    * for wide characters allocated 16-bits for A_CHARTEXT, leaving too few
    * bits for a few of the A_xxx symbols.
+   * Some preprocessors are not able to test the values because they
+   * now (2014) contain an explicit cast to chtype, so we avoid ifdef.
    */
   static const name_attribute_pair nap[] =
   {
-#ifdef A_STANDOUT
     {"Stand_Out", A_STANDOUT},
-#endif
-#ifdef A_UNDERLINE
     {"Under_Line", A_UNDERLINE},
-#endif
-#ifdef A_REVERSE
     {"Reverse_Video", A_REVERSE},
-#endif
-#ifdef A_BLINK
     {"Blink", A_BLINK},
-#endif
-#ifdef A_DIM
     {"Dim_Character", A_DIM},
-#endif
-#ifdef A_BOLD
     {"Bold_Character", A_BOLD},
-#endif
-#ifdef A_ALTCHARSET
     {"Alternate_Character_Set", A_ALTCHARSET},
-#endif
-#ifdef A_INVIS
     {"Invisible_Character", A_INVIS},
-#endif
-#ifdef A_PROTECT
     {"Protected_Character", A_PROTECT},
-#endif
-#ifdef A_HORIZONTAL
     {"Horizontal", A_HORIZONTAL},
-#endif
-#ifdef A_LEFT
     {"Left", A_LEFT},
-#endif
-#ifdef A_LOW
     {"Low", A_LOW},
-#endif
-#ifdef A_RIGHT
     {"Right", A_RIGHT},
-#endif
-#ifdef A_TOP
     {"Top", A_TOP},
-#endif
-#ifdef A_VERTICAL
     {"Vertical", A_VERTICAL},
-#endif
     {(char *)0, 0}
   };
   chtype attr = A_ATTRIBUTES & ~A_COLOR;
Index: NEWS
Prereq:  1.2155 
--- ncurses-5.9-20140118+/NEWS	2014-01-18 23:59:51.000000000 +0000
+++ ncurses-5.9-20140125/NEWS	2014-01-26 00:20:39.000000000 +0000
@@ -25,7 +25,7 @@
 -- sale, use or other dealings in this Software without prior written        --
 -- authorization.                                                            --
 -------------------------------------------------------------------------------
--- $Id: NEWS,v 1.2155 2014/01/18 23:59:51 tom Exp $
+-- $Id: NEWS,v 1.2157 2014/01/26 00:20:39 tom Exp $
 -------------------------------------------------------------------------------
 
 This is a log of changes that ncurses has gone through since Zeyd started
@@ -45,6 +45,12 @@
 Changes through 1.9.9e did not credit all contributions;
 it is not possible to add this information.
 
+20140125
+	+ remove unnecessary ifdef's in Ada95/gen/gen.c, which reportedly do
+	  not work as is with gcc 4.8 due to fixes using chtype cast made for
+	  new compiler warnings by gcc 4.8 in 20130824 (Debian #735753, patch
+	  by Nicolas Boulenguez).
+
 20140118
 	+ apply includesubdir variable which was introduced in 20130805 to
 	  gen-pkgconfig.in (Debian #735782).
Index: dist.mk
Prereq:  1.967 
--- ncurses-5.9-20140118+/dist.mk	2014-01-19 00:00:07.000000000 +0000
+++ ncurses-5.9-20140125/dist.mk	2014-01-25 16:16:43.000000000 +0000
@@ -25,7 +25,7 @@
 # use or other dealings in this Software without prior written               #
 # authorization.                                                             #
 ##############################################################################
-# $Id: dist.mk,v 1.967 2014/01/19 00:00:07 tom Exp $
+# $Id: dist.mk,v 1.968 2014/01/25 16:16:43 tom Exp $
 # Makefile for creating ncurses distributions.
 #
 # This only needs to be used directly as a makefile by developers, but
@@ -37,7 +37,7 @@
 # These define the major/minor/patch versions of ncurses.
 NCURSES_MAJOR = 5
 NCURSES_MINOR = 9
-NCURSES_PATCH = 20140118
+NCURSES_PATCH = 20140125
 
 # We don't append the patch to the version, since this only applies to releases
 VERSION = $(NCURSES_MAJOR).$(NCURSES_MINOR)
Index: package/debian-mingw/changelog
--- ncurses-5.9-20140118+/package/debian-mingw/changelog	2014-01-18 15:54:25.000000000 +0000
+++ ncurses-5.9-20140125/package/debian-mingw/changelog	2014-01-25 16:16:43.000000000 +0000
@@ -1,8 +1,8 @@
-ncurses6 (5.9-20140118) unstable; urgency=low
+ncurses6 (5.9-20140125) unstable; urgency=low
 
   * latest weekly patch
 
- -- Thomas E. Dickey <dickey@invisible-island.net>  Sat, 18 Jan 2014 10:54:25 -0500
+ -- Thomas E. Dickey <dickey@invisible-island.net>  Sat, 25 Jan 2014 11:16:43 -0500
 
 ncurses6 (5.9-20131005) unstable; urgency=low
 
Index: package/debian-mingw64/changelog
--- ncurses-5.9-20140118+/package/debian-mingw64/changelog	2014-01-18 15:54:25.000000000 +0000
+++ ncurses-5.9-20140125/package/debian-mingw64/changelog	2014-01-25 16:16:43.000000000 +0000
@@ -1,8 +1,8 @@
-ncurses6 (5.9-20140118) unstable; urgency=low
+ncurses6 (5.9-20140125) unstable; urgency=low
 
   * latest weekly patch
 
- -- Thomas E. Dickey <dickey@invisible-island.net>  Sat, 18 Jan 2014 10:54:25 -0500
+ -- Thomas E. Dickey <dickey@invisible-island.net>  Sat, 25 Jan 2014 11:16:43 -0500
 
 ncurses6 (5.9-20131005) unstable; urgency=low
 
Index: package/debian/changelog
--- ncurses-5.9-20140118+/package/debian/changelog	2014-01-18 15:54:25.000000000 +0000
+++ ncurses-5.9-20140125/package/debian/changelog	2014-01-25 16:16:43.000000000 +0000
@@ -1,8 +1,8 @@
-ncurses6 (5.9-20140118) unstable; urgency=low
+ncurses6 (5.9-20140125) unstable; urgency=low
 
   * latest weekly patch
 
- -- Thomas E. Dickey <dickey@invisible-island.net>  Sat, 18 Jan 2014 10:54:25 -0500
+ -- Thomas E. Dickey <dickey@invisible-island.net>  Sat, 25 Jan 2014 11:16:43 -0500
 
 ncurses6 (5.9-20120608) unstable; urgency=low
 
Index: package/mingw-ncurses.nsi
Prereq:  1.21 
--- ncurses-5.9-20140118+/package/mingw-ncurses.nsi	2014-01-18 15:54:25.000000000 +0000
+++ ncurses-5.9-20140125/package/mingw-ncurses.nsi	2014-01-25 16:16:43.000000000 +0000
@@ -1,4 +1,4 @@
-; $Id: mingw-ncurses.nsi,v 1.21 2014/01/18 15:54:25 tom Exp $
+; $Id: mingw-ncurses.nsi,v 1.22 2014/01/25 16:16:43 tom Exp $
 
 ; TODO add examples
 ; TODO bump ABI to 6
@@ -10,7 +10,7 @@
 !define VERSION_MAJOR "5"
 !define VERSION_MINOR "9"
 !define VERSION_YYYY  "2014"
-!define VERSION_MMDD  "118"
+!define VERSION_MMDD  "125"
 !define VERSION_PATCH ${VERSION_YYYY}${VERSION_MMDD}
 
 !define MY_ABI   "5"
Index: package/mingw-ncurses.spec
--- ncurses-5.9-20140118+/package/mingw-ncurses.spec	2014-01-18 15:54:25.000000000 +0000
+++ ncurses-5.9-20140125/package/mingw-ncurses.spec	2014-01-25 16:16:43.000000000 +0000
@@ -3,7 +3,7 @@
 Summary: shared libraries for terminal handling
 Name: mingw32-ncurses6
 Version: 5.9
-Release: 20140118
+Release: 20140125
 License: X11
 Group: Development/Libraries
 Source: ncurses-%{version}-%{release}.tgz
Index: package/ncurses.spec
--- ncurses-5.9-20140118+/package/ncurses.spec	2014-01-18 15:54:25.000000000 +0000
+++ ncurses-5.9-20140125/package/ncurses.spec	2014-01-25 16:16:43.000000000 +0000
@@ -1,7 +1,7 @@
 Summary: shared libraries for terminal handling
 Name: ncurses6
 Version: 5.9
-Release: 20140118
+Release: 20140125
 License: X11
 Group: Development/Libraries
 Source: ncurses-%{version}-%{release}.tgz
